@@ -14,12 +14,12 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
-    CreateTokenResponseResponseTypeDef,
-    RegisterClientResponseResponseTypeDef,
-    StartDeviceAuthorizationResponseResponseTypeDef,
+    CreateTokenResponseTypeDef,
+    RegisterClientResponseTypeDef,
+    StartDeviceAuthorizationResponseTypeDef,
 )
 
 __all__ = ("SSOOIDCClient",)
@@ -49,20 +49,25 @@ class Exceptions:
     UnsupportedGrantTypeException: Type[BotocoreClientError]
 
 
-class SSOOIDCClient:
+class SSOOIDCClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-oidc.html#SSOOIDC.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        SSOOIDCClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#can_paginate)
         """
 
@@ -77,11 +82,11 @@ class SSOOIDCClient:
         refreshToken: str = None,
         scope: List[str] = None,
         redirectUri: str = None
-    ) -> CreateTokenResponseResponseTypeDef:
+    ) -> CreateTokenResponseTypeDef:
         """
         Creates and returns an access token for the authorized client.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#create_token)
         """
 
@@ -95,27 +100,27 @@ class SSOOIDCClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#generate_presigned_url)
         """
 
     def register_client(
         self, *, clientName: str, clientType: str, scopes: List[str] = None
-    ) -> RegisterClientResponseResponseTypeDef:
+    ) -> RegisterClientResponseTypeDef:
         """
         Registers a client with AWS SSO.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#register_client)
         """
 
     def start_device_authorization(
         self, *, clientId: str, clientSecret: str, startUrl: str
-    ) -> StartDeviceAuthorizationResponseResponseTypeDef:
+    ) -> StartDeviceAuthorizationResponseTypeDef:
         """
         Initiates device authorization by requesting a pair of verification codes from
         the authorization service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#start_device_authorization)
         """
